@@ -3,7 +3,7 @@ Contains Buendelvertrag class and corresponding marshmallow schema for de-/seria
 """
 from typing import List
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.bo.geschaeftsobjekt import Geschaeftsobjekt, GeschaeftsobjektSchema
@@ -13,7 +13,7 @@ from bo4e.validators import check_list_length_at_least_one
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Buendelvertrag(Geschaeftsobjekt):
     """
     Abbildung eines Bündelvertrags.
@@ -25,11 +25,11 @@ class Buendelvertrag(Geschaeftsobjekt):
     """
 
     # required attributes
-    bo_typ: BoTyp = attr.ib(default=BoTyp.BUENDELVERTRAG)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.BUENDELVERTRAG)
     #: Die Liste mit den Einzelverträgen zu den Abnahmestellen
-    einzelvertraege: List[Vertrag] = attr.ib(
-        validator=attr.validators.deep_iterable(
-            member_validator=attr.validators.instance_of(Vertrag), iterable_validator=check_list_length_at_least_one
+    einzelvertraege: List[Vertrag] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(Vertrag), iterable_validator=check_list_length_at_least_one
         )
     )
 
