@@ -2,7 +2,7 @@
 Contains PreisblattKonzessionsabgabe class and corresponding marshmallow schema for de-/serialization
 """
 
-import attr
+import attrs
 from marshmallow_enum import EnumField  # type:ignore[import]
 
 from bo4e.bo.preisblatt import Preisblatt, PreisblattSchema
@@ -11,7 +11,7 @@ from bo4e.enum.kundengruppeka import KundengruppeKA
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class PreisblattKonzessionsabgabe(Preisblatt):
     """
     Die Variante des Preisblattmodells zur Abbildung von allgemeinen Abgaben
@@ -21,10 +21,10 @@ class PreisblattKonzessionsabgabe(Preisblatt):
 
     """
 
-    bo_typ: BoTyp = attr.ib(default=BoTyp.PREISBLATTKONZESSIONSABGABE)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.PREISBLATTKONZESSIONSABGABE)
     # required attributes (additional to those of Preisblatt)
     #: Kundegruppe anhand derer die Höhe der Konzessionabgabe festgelegt ist
-    kundengruppe_k_a: KundengruppeKA = attr.ib(validator=attr.validators.instance_of(KundengruppeKA))
+    kundengruppe_k_a: KundengruppeKA = attrs.field(validator=attrs.validators.instance_of(KundengruppeKA))
 
     # there are no optional attributes (additionally to those of Preisblatt)
 
