@@ -3,7 +3,7 @@ Contains PreisblattMessung class and corresponding marshmallow schema for de-/se
 """
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -16,7 +16,7 @@ from bo4e.enum.netzebene import Netzebene
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class PreisblattMessung(Preisblatt):
     """
     Variante des Preisblattmodells zur Abbildung der Preise des Messstellenbetriebs und damit verbundener Leistungen
@@ -26,36 +26,38 @@ class PreisblattMessung(Preisblatt):
 
     """
 
-    bo_typ: BoTyp = attr.ib(default=BoTyp.PREISBLATTMESSUNG)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.PREISBLATTMESSUNG)
     # required attributes (additional to those of Preisblatt)
     #: Die Preise gelten für Marktlokationen der angebebenen Bilanzierungsmethode
-    bilanzierungsmethode: Bilanzierungsmethode = attr.ib(validator=attr.validators.instance_of(Bilanzierungsmethode))
+    bilanzierungsmethode: Bilanzierungsmethode = attrs.field(
+        validator=attrs.validators.instance_of(Bilanzierungsmethode)
+    )
     #: Die Preise gelten für Messlokationen in der angebebenen Netzebene
-    messebene: Netzebene = attr.ib(validator=attr.validators.instance_of(Netzebene))
+    messebene: Netzebene = attrs.field(validator=attrs.validators.instance_of(Netzebene))
 
     #: Der Preis betrifft den hier angegebenen Zähler, z.B. einen Drehstromzähler
-    zaehler: Geraeteeigenschaften = attr.ib(validator=attr.validators.instance_of(Geraeteeigenschaften))
+    zaehler: Geraeteeigenschaften = attrs.field(validator=attrs.validators.instance_of(Geraeteeigenschaften))
     # todo: https://github.com/Hochfrequenz/BO4E-python/issues/333
 
     # optional attributes
     #: Im Preis sind die hier angegebenen Dienstleistungen enthalten, z.B. Jährliche Ablesung
-    inklusive_dienstleistungen: Optional[List[Dienstleistungstyp]] = attr.ib(
+    inklusive_dienstleistungen: Optional[List[Dienstleistungstyp]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(Dienstleistungstyp),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(Dienstleistungstyp),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
 
     #: Im Preis sind die hier angegebenen Geräte mit enthalten, z.B. ein Wandler
-    inklusive_geraete: Optional[List[Geraeteeigenschaften]] = attr.ib(
+    inklusive_geraete: Optional[List[Geraeteeigenschaften]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(Geraeteeigenschaften),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(Geraeteeigenschaften),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
