@@ -5,7 +5,7 @@ Contains Regionaltarif class and corresponding marshmallow schema for de-/serial
 from datetime import datetime
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.bo.tarifinfo import Tarifinfo, TarifinfoSchema
@@ -19,7 +19,7 @@ from bo4e.validators import check_list_length_at_least_one
 
 
 # pylint: disable=too-few-public-methods, empty-docstring
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Regionaltarif(Tarifinfo):
     # no description in the official docs.
     # https://github.com/Hochfrequenz/BO4E-python/issues/338
@@ -30,46 +30,46 @@ class Regionaltarif(Tarifinfo):
 
     """
 
-    bo_typ: BoTyp = attr.ib(default=BoTyp.REGIONALTARIF)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.REGIONALTARIF)
     # required attributes
     #: Gibt an, wann der Preis zuletzt angepasst wurde
-    preisstand: datetime = attr.ib(validator=attr.validators.instance_of(datetime))
+    preisstand: datetime = attrs.field(validator=attrs.validators.instance_of(datetime))
     #: Für die Berechnung der Kosten sind die hier abgebildeten Parameter heranzuziehen
-    berechnungsparameter: Tarifberechnungsparameter = attr.ib(
-        validator=attr.validators.instance_of(Tarifberechnungsparameter)
+    berechnungsparameter: Tarifberechnungsparameter = attrs.field(
+        validator=attrs.validators.instance_of(Tarifberechnungsparameter)
     )
     #: Die festgelegten Preise mit regionaler Eingrenzung, z.B. für Arbeitspreis, Grundpreis etc.
-    tarifpreise: List[RegionaleTarifpreisposition] = attr.ib(
-        validator=attr.validators.deep_iterable(
-            member_validator=attr.validators.instance_of(RegionaleTarifpreisposition),
+    tarifpreise: List[RegionaleTarifpreisposition] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(RegionaleTarifpreisposition),
             iterable_validator=check_list_length_at_least_one,
         )
     )
 
     # optional attributes
     #: Auf- und Abschläge auf die Preise oder Kosten mit regionaler Eingrenzung
-    tarif_auf_abschlaege: Optional[List[RegionalerAufAbschlag]] = attr.ib(
+    tarif_auf_abschlaege: Optional[List[RegionalerAufAbschlag]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(RegionalerAufAbschlag),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(RegionalerAufAbschlag),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
     #: Festlegung von Garantien für bestimmte Preisanteile
-    preisgarantien: Optional[List[RegionalePreisgarantie]] = attr.ib(
+    preisgarantien: Optional[List[RegionalePreisgarantie]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(RegionalePreisgarantie),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(RegionalePreisgarantie),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
     #: Die Bedingungen und Einschränkungen unter denen ein Tarif angewendet werden kann
-    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(Tarifeinschraenkung))
+    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(Tarifeinschraenkung))
     )
 
 
