@@ -5,7 +5,7 @@ Contains Tarif class and corresponding marshmallow schema for de-/serialization
 from datetime import datetime
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.bo.tarifinfo import Tarifinfo, TarifinfoSchema
@@ -19,7 +19,7 @@ from bo4e.validators import check_list_length_at_least_one
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Tarif(Tarifinfo):
     """
     Abbildung eines Tarifs mit regionaler Zuordnung von Preisen und Auf- und Abschlägen
@@ -29,30 +29,30 @@ class Tarif(Tarifinfo):
 
     """
 
-    bo_typ: BoTyp = attr.ib(default=BoTyp.TARIF)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.TARIF)
     # required attributes
     #: Gibt an, wann der Preis zuletzt angepasst wurde
-    preisstand: datetime = attr.ib(validator=attr.validators.instance_of(datetime))
+    preisstand: datetime = attrs.field(validator=attrs.validators.instance_of(datetime))
     #: Für die Berechnung der Kosten sind die hier abgebildeten Parameter heranzuziehen
-    berechnungsparameter: Tarifberechnungsparameter = attr.ib(
-        validator=attr.validators.instance_of(Tarifberechnungsparameter)
+    berechnungsparameter: Tarifberechnungsparameter = attrs.field(
+        validator=attrs.validators.instance_of(Tarifberechnungsparameter)
     )
     #: Die festgelegten Preise mit regionaler Eingrenzung z.B. für Arbeitspreis, Grundpreis etc.
-    tarifpreise: List[TarifpreispositionProOrt] = attr.ib(
-        validator=attr.validators.deep_iterable(
-            member_validator=attr.validators.instance_of(TarifpreispositionProOrt),
+    tarifpreise: List[TarifpreispositionProOrt] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(TarifpreispositionProOrt),
             iterable_validator=check_list_length_at_least_one,
         )
     )
 
     # optional attributes
     #: Auf- und Abschläge auf die Preise oder Kosten mit regionaler Eingrenzung
-    tarif_auf_abschlaege: Optional[List[AufAbschlagRegional]] = attr.ib(
+    tarif_auf_abschlaege: Optional[List[AufAbschlagRegional]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(AufAbschlagRegional),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(AufAbschlagRegional),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
@@ -60,16 +60,16 @@ class Tarif(Tarifinfo):
     # https://github.com/Hochfrequenz/BO4E-python/issues/345
 
     #: Preisgarantie für diesen Tarif
-    preisgarantie: Optional[Preisgarantie] = attr.ib(
+    preisgarantie: Optional[Preisgarantie] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.instance_of(Preisgarantie),
+        validator=attrs.validators.optional(
+            attrs.validators.instance_of(Preisgarantie),
         ),
     )
     # todo: fix inconsistency with regionaltarif https://github.com/Hochfrequenz/BO4E-python/issues/346
     #: Die Bedingungen und Einschränkungen unter denen ein Tarif angewendet werden kann
-    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(Tarifeinschraenkung))
+    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(Tarifeinschraenkung))
     )
 
 
