@@ -4,7 +4,7 @@ Contains Tarifpreisblatt class and corresponding marshmallow schema for de-/seri
 from datetime import datetime
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.bo.tarifinfo import Tarifinfo, TarifinfoSchema
@@ -18,7 +18,7 @@ from bo4e.validators import check_list_length_at_least_one
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Tarifpreisblatt(Tarifinfo):
     """
     Tarifinformation mit Preisen, Aufschlägen und Berechnungssystematik
@@ -28,38 +28,38 @@ class Tarifpreisblatt(Tarifinfo):
 
     """
 
-    bo_typ: BoTyp = attr.ib(default=BoTyp.TARIFPREISBLATT)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.TARIFPREISBLATT)
     # required attributes (additional to those of Tarifinfo)
     #: Gibt an, wann der Preis zuletzt angepasst wurde
-    preisstand: datetime = attr.ib(validator=attr.validators.instance_of(datetime))
+    preisstand: datetime = attrs.field(validator=attrs.validators.instance_of(datetime))
     #: Die festgelegten Preise, z.B. für Arbeitspreis, Grundpreis etc.
-    tarifpreise: List[Tarifpreisposition] = attr.ib(
-        validator=attr.validators.deep_iterable(
-            member_validator=attr.validators.instance_of(Tarifpreisposition),
+    tarifpreise: List[Tarifpreisposition] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(Tarifpreisposition),
             iterable_validator=check_list_length_at_least_one,
         )
     )
     #: Für die Berechnung der Kosten sind die hier abgebildeten Parameter heranzuziehen
-    berechnungsparameter: Tarifberechnungsparameter = attr.ib(
-        validator=attr.validators.instance_of(Tarifberechnungsparameter)
+    berechnungsparameter: Tarifberechnungsparameter = attrs.field(
+        validator=attrs.validators.instance_of(Tarifberechnungsparameter)
     )
 
     # optional attributes
     #: Die Bedingungen und Einschränkungen unter denen ein Tarif angewendet werden kann
-    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(Tarifeinschraenkung))
+    tarifeinschraenkung: Optional[Tarifeinschraenkung] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(Tarifeinschraenkung))
     )
     #: Festlegung von Garantien für bestimmte Preisanteile
-    preisgarantie: Optional[Preisgarantie] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(Preisgarantie))
+    preisgarantie: Optional[Preisgarantie] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(Preisgarantie))
     )
     #: Auf- und Abschläge auf die Preise oder Kosten
-    tarif_auf_abschlaege: Optional[List[AufAbschlag]] = attr.ib(
+    tarif_auf_abschlaege: Optional[List[AufAbschlag]] = attrs.field(
         default=None,
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(AufAbschlag),
-                iterable_validator=attr.validators.instance_of(list),
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(AufAbschlag),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
     )
