@@ -5,7 +5,7 @@ and corresponding marshmallow schema for de-/serialization
 from datetime import datetime
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -30,7 +30,7 @@ def at_least_one_vertragsteil(instance, attribute, value):
 
 
 # pylint: disable=too-many-instance-attributes, too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Vertrag(Geschaeftsobjekt):
     """
     Modell für die Abbildung von Vertragsbeziehungen;
@@ -42,33 +42,33 @@ class Vertrag(Geschaeftsobjekt):
     """
 
     # required attributes
-    bo_typ: BoTyp = attr.ib(default=BoTyp.VERTRAG)
+    bo_typ: BoTyp = attrs.field(default=BoTyp.VERTRAG)
     #: Eine im Verwendungskontext eindeutige Nummer für den Vertrag
-    vertragsnummer: str = attr.ib(validator=attr.validators.instance_of(str))
+    vertragsnummer: str = attrs.field(validator=attrs.validators.instance_of(str))
     #: Hier ist festgelegt, um welche Art von Vertrag es sich handelt.
-    vertragsart: Vertragsart = attr.ib(validator=attr.validators.instance_of(Vertragsart))
+    vertragsart: Vertragsart = attrs.field(validator=attrs.validators.instance_of(Vertragsart))
     #: Gibt den Status des Vertrags an
-    vertragsstatus: Vertragsstatus = attr.ib(validator=attr.validators.instance_of(Vertragsstatus))
+    vertragsstatus: Vertragsstatus = attrs.field(validator=attrs.validators.instance_of(Vertragsstatus))
     #: Unterscheidungsmöglichkeiten für die Sparte
-    sparte: Sparte = attr.ib(validator=attr.validators.instance_of(Sparte))
+    sparte: Sparte = attrs.field(validator=attrs.validators.instance_of(Sparte))
     #: Gibt an, wann der Vertrag beginnt (inklusiv)
-    vertragsbeginn: datetime = attr.ib(validator=attr.validators.instance_of(datetime))
+    vertragsbeginn: datetime = attrs.field(validator=attrs.validators.instance_of(datetime))
     #: Gibt an, wann der Vertrag (voraussichtlich) endet oder beendet wurde (exklusiv)
-    vertragsende: datetime = attr.ib(validator=attr.validators.instance_of(datetime))
+    vertragsende: datetime = attrs.field(validator=attrs.validators.instance_of(datetime))
     # todo: add von/bis validator
-    vertragspartner1: Geschaeftspartner = attr.ib(validator=attr.validators.instance_of(Geschaeftspartner))
+    vertragspartner1: Geschaeftspartner = attrs.field(validator=attrs.validators.instance_of(Geschaeftspartner))
     """
     Der "erstgenannte" Vertragspartner.
     In der Regel der Aussteller des Vertrags.
     Beispiel: "Vertrag zwischen Vertragspartner 1 ..."
     """
-    vertragspartner2: Geschaeftspartner = attr.ib(validator=attr.validators.instance_of(Geschaeftspartner))
+    vertragspartner2: Geschaeftspartner = attrs.field(validator=attrs.validators.instance_of(Geschaeftspartner))
     """
     Der "zweitgenannte" Vertragspartner.
     In der Regel der Empfänger des Vertrags.
     Beispiel "Vertrag zwischen Vertragspartner 1 und Vertragspartner 2".
     """
-    vertragsteile: List[Vertragsteil] = attr.ib(validator=at_least_one_vertragsteil)
+    vertragsteile: List[Vertragsteil] = attrs.field(validator=at_least_one_vertragsteil)
     """
     Der Vertragsteil wird dazu verwendet, eine vertragliche Leistung in Bezug zu einer Lokation
     (Markt- oder Messlokation) festzulegen.
@@ -76,13 +76,13 @@ class Vertrag(Geschaeftsobjekt):
 
     # optional attributes
     #: Beschreibung zum Vertrag
-    beschreibung: Optional[str] = attr.ib(default=None)
+    beschreibung: Optional[str] = attrs.field(default=None)
     #: Festlegungen zu Laufzeiten und Kündigungsfristen
-    vertragskonditionen: Optional[Vertragskonditionen] = attr.ib(default=None)
+    vertragskonditionen: Optional[Vertragskonditionen] = attrs.field(default=None)
     #: Unterzeichner des Vertragspartners 1
-    unterzeichnervp1: Optional[List[Unterschrift]] = attr.ib(default=None)
+    unterzeichnervp1: Optional[List[Unterschrift]] = attrs.field(default=None)
     #: Unterzeichner des Vertragspartners 2
-    unterzeichnervp2: Optional[List[Unterschrift]] = attr.ib(default=None)
+    unterzeichnervp2: Optional[List[Unterschrift]] = attrs.field(default=None)
 
 
 class VertragSchema(GeschaeftsobjektSchema):
