@@ -2,14 +2,14 @@
 Contains ExterenzeReferenz class
 and corresponding marshmallow schema for de-/serialization
 """
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.com.com import COM, COMSchema
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class ExterneReferenz(COM):
     """
     Viele Datenobjekte weisen in unterschiedlichen Systemen eine eindeutige ID (Kundennummer, GP-Nummer etc.) auf.
@@ -22,8 +22,8 @@ class ExterneReferenz(COM):
     """
 
     # required attributes
-    ex_ref_name: str
-    ex_ref_wert: str
+    ex_ref_name: str  #: Bezeichnung der externen Referenz (z.B. "microservice xyz" oder "SAP CRM GP-Nummer")
+    ex_ref_wert: str  #: Wert der externen Referenz (z.B. "123456"; "4711")
 
 
 class ExterneReferenzSchema(COMSchema):
