@@ -5,7 +5,7 @@ and corresponding marshmallow schema for de-/serialization
 
 from typing import Optional
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.com.com import COM, COMSchema
@@ -13,7 +13,7 @@ from bo4e.com.geraeteeigenschaften import Geraeteeigenschaften, Geraeteeigenscha
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Geraet(COM):
     """
     Mit dieser Komponente werden alle Geräte modelliert, die keine Zähler sind.
@@ -25,12 +25,12 @@ class Geraet(COM):
 
     # optional attributes
     #: Die auf dem Gerät aufgedruckte Nummer, die vom MSB vergeben wird.
-    geraetenummer: Optional[str] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(str))
+    geraetenummer: Optional[str] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(str))
     )
     #: Festlegung der Eigenschaften des Gerätes. Z.B. Wandler MS/NS.
-    geraeteeigenschaften: Optional[Geraeteeigenschaften] = attr.ib(
-        default=None, validator=attr.validators.optional(attr.validators.instance_of(Geraeteeigenschaften))
+    geraeteeigenschaften: Optional[Geraeteeigenschaften] = attrs.field(
+        default=None, validator=attrs.validators.optional(attrs.validators.instance_of(Geraeteeigenschaften))
     )
 
 
@@ -41,5 +41,5 @@ class GeraetSchema(COMSchema):
 
     class_name = Geraet
     # optional attributes
-    geraetenummer = fields.Str(missing=None)
+    geraetenummer = fields.Str(load_default=None)
     geraeteeigenschaften = fields.Nested(GeraeteeigenschaftenSchema, missing=None)
