@@ -3,7 +3,7 @@ Contains Hardware class
 and corresponding marshmallow schema for de-/serialization
 """
 
-import attr
+import attrs
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -12,10 +12,10 @@ from bo4e.enum.geraetetyp import Geraetetyp
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Hardware(COM):
     """
-    Abbildung einer abrechenbaren Hardware.
+    Abbildung einer abrechenbaren Hardware
 
     .. HINT::
         `Hardware JSON Schema <https://json-schema.app/view/%23?url=https://raw.githubusercontent.com/Hochfrequenz/BO4E-python/main/json_schemas/com/HardwareSchema.json>`_
@@ -23,8 +23,10 @@ class Hardware(COM):
     """
 
     # required attributes
-    geraetetyp: Geraetetyp = attr.ib(validator=attr.validators.in_(Geraetetyp))
-    bezeichnung: str = attr.ib(validator=attr.validators.instance_of(str))
+    #: Eindeutiger Typ der Hardware
+    geraetetyp: Geraetetyp = attrs.field(validator=attrs.validators.in_(Geraetetyp))
+    #: Bezeichnung der Hardware
+    bezeichnung: str = attrs.field(validator=attrs.validators.instance_of(str))
 
 
 class HardwareSchema(COMSchema):
