@@ -2,7 +2,7 @@
 Contains RegionalePreisstaffel class and corresponding marshmallow schema for de-/serialization
 """
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.com.preisstaffel import Preisstaffel, PreisstaffelSchema
@@ -10,7 +10,7 @@ from bo4e.com.regionalegueltigkeit import RegionaleGueltigkeit, RegionaleGueltig
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class RegionalePreisstaffel(Preisstaffel):
     """
     Abbildung einer Preisstaffel mit regionaler Abgrenzung
@@ -22,7 +22,9 @@ class RegionalePreisstaffel(Preisstaffel):
 
     # required attributes
     #: Regionale Eingrenzung der Preisstaffel
-    regionale_gueltigkeit: RegionaleGueltigkeit = attr.ib(validator=attr.validators.instance_of(RegionaleGueltigkeit))
+    regionale_gueltigkeit: RegionaleGueltigkeit = attrs.field(
+        validator=attrs.validators.instance_of(RegionaleGueltigkeit)
+    )
 
 
 class RegionalePreisstaffelSchema(PreisstaffelSchema):
