@@ -4,7 +4,7 @@ Contains RegionalerAufAbschlag class and corresponding marshmallow schema for de
 
 from typing import List, Optional
 
-import attr
+import attrs
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -22,7 +22,7 @@ from bo4e.validators import check_list_length_at_least_one
 
 
 # pylint: disable=too-few-public-methods, too-many-instance-attributes
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class RegionalerAufAbschlag(COM):
     """
     Mit dieser Komponente können Auf- und Abschläge verschiedener Typen im Zusammenhang mit regionalen Gültigkeiten
@@ -37,96 +37,100 @@ class RegionalerAufAbschlag(COM):
 
     # required attributes
     #: Bezeichnung des Auf-/Abschlags
-    bezeichnung: str = attr.ib(validator=attr.validators.instance_of(str))
+    bezeichnung: str = attrs.field(validator=attrs.validators.instance_of(str))
 
     #: Werte für die gestaffelten Auf/Abschläge mit regionaler Eingrenzung
-    staffeln: List[RegionalePreisstaffel] = attr.ib(
-        validator=attr.validators.deep_iterable(
-            member_validator=attr.validators.instance_of(RegionalePreisstaffel),
+    staffeln: List[RegionalePreisstaffel] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(RegionalePreisstaffel),
             iterable_validator=check_list_length_at_least_one,
         )
     )
 
     # optional attributes
     #: Beschreibung des Auf-/Abschlags
-    beschreibung: Optional[str] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(str)), default=None
+    beschreibung: Optional[str] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(str)), default=None
     )
 
     #: Typ des Aufabschlages (z.B. absolut oder prozentual)
-    auf_abschlagstyp: Optional[AufAbschlagstyp] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(AufAbschlagstyp)), default=None
+    auf_abschlagstyp: Optional[AufAbschlagstyp] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(AufAbschlagstyp)), default=None
     )
 
     #: Diesem Preis oder den Kosten ist der Auf/Abschlag zugeordnet. Z.B. Arbeitspreis, Gesamtpreis etc.
-    auf_abschlagsziel: Optional[AufAbschlagsziel] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(AufAbschlagsziel)), default=None
+    auf_abschlagsziel: Optional[AufAbschlagsziel] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(AufAbschlagsziel)), default=None
     )
 
     #: Gibt an in welcher Währungseinheit der Auf/Abschlag berechnet wird (nur im Falle absoluter Aufschlagstypen).
-    einheit: Optional[Waehrungseinheit] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Waehrungseinheit)), default=None
+    einheit: Optional[Waehrungseinheit] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Waehrungseinheit)), default=None
     )
 
     #: Internetseite, auf der die Informationen zum Auf-/Abschlag veröffentlicht sind
-    website: Optional[str] = attr.ib(validator=attr.validators.optional(attr.validators.instance_of(str)), default=None)
+    website: Optional[str] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(str)), default=None
+    )
 
     #: Zusatzprodukte, die nur in Kombination mit diesem AufAbschlag erhältlich sind
-    zusatzprodukte: Optional[List[str]] = attr.ib(
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(str), iterable_validator=attr.validators.instance_of(list)
+    zusatzprodukte: Optional[List[str]] = attrs.field(
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(str),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
         default=None,
     )
 
     #: Voraussetzungen, die erfüllt sein müssen, damit dieser AufAbschlag zur Anwendung kommen kann
-    voraussetzungen: Optional[List[str]] = attr.ib(
-        validator=attr.validators.optional(
-            attr.validators.deep_iterable(
-                member_validator=attr.validators.instance_of(str), iterable_validator=attr.validators.instance_of(list)
+    voraussetzungen: Optional[List[str]] = attrs.field(
+        validator=attrs.validators.optional(
+            attrs.validators.deep_iterable(
+                member_validator=attrs.validators.instance_of(str),
+                iterable_validator=attrs.validators.instance_of(list),
             )
         ),
         default=None,
     )
 
     #: Durch die Anwendung des Auf/Abschlags kann eine Änderung des Tarifnamens auftreten
-    tarifnamensaenderungen: Optional[str] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(str)), default=None
+    tarifnamensaenderungen: Optional[str] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(str)), default=None
     )
 
     #: Zeitraum, in dem der Abschlag zur Anwendung kommen kann
-    gueltigkeitszeitraum: Optional[Zeitraum] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Zeitraum)), default=None
+    gueltigkeitszeitraum: Optional[Zeitraum] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Zeitraum)), default=None
     )
 
-    energiemixaenderung: Optional[Energiemix] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Energiemix)), default=None
+    energiemixaenderung: Optional[Energiemix] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Energiemix)), default=None
     )
     """
     Der Energiemix kann sich durch einen AufAbschlag ändern (z.B. zwei Cent Aufschlag für Ökostrom).
     Sollte dies der Fall sein, wird hier die neue Zusammensetzung des Energiemix angegeben.
     """
 
-    vertagskonditionsaenderung: Optional[Vertragskonditionen] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Vertragskonditionen)), default=None
+    vertagskonditionsaenderung: Optional[Vertragskonditionen] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Vertragskonditionen)), default=None
     )
     """
     Änderungen in den Vertragskonditionen;
     Falls in dieser Komponenten angegeben, werden die Tarifparameter hiermit überschrieben.
     """
 
-    garantieaenderung: Optional[Preisgarantie] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Preisgarantie)), default=None
+    garantieaenderung: Optional[Preisgarantie] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Preisgarantie)), default=None
     )
     """
     Änderungen in den Garantievereinbarungen;
     Falls in dieser Komponenten angegeben, werden die Tarifparameter hiermit überschrieben.
     """
 
-    einschraenkungsaenderung: Optional[Tarifeinschraenkung] = attr.ib(
-        validator=attr.validators.optional(attr.validators.instance_of(Tarifeinschraenkung)), default=None
+    einschraenkungsaenderung: Optional[Tarifeinschraenkung] = attrs.field(
+        validator=attrs.validators.optional(attrs.validators.instance_of(Tarifeinschraenkung)), default=None
     )
     """
     Änderungen in den Einschränkungen zum Tarif;
