@@ -3,14 +3,14 @@ Contains StandorteigenschaftenStrom class
 and corresponding marshmallow schema for de-/serialization
 """
 
-import attr
+import attrs
 from marshmallow import fields
 
 from bo4e.com.com import COM, COMSchema
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class StandorteigenschaftenStrom(COM):
     """
     Standorteigenschaften der Sparte Strom
@@ -22,14 +22,14 @@ class StandorteigenschaftenStrom(COM):
 
     # required attributes
     #: Die EIC-Nummer des Bilanzierungsgebietes
-    bilanzierungsgebiet_eic: str = attr.ib(validator=attr.validators.instance_of(str))
+    bilanzierungsgebiet_eic: str = attrs.field(validator=attrs.validators.instance_of(str))
     # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147
 
     #: Der Name der Regelzone
-    regelzone: str = attr.ib(validator=attr.validators.instance_of(str))
+    regelzone: str = attrs.field(validator=attrs.validators.instance_of(str))
 
     #: De EIC-Nummer der Regelzone
-    regelzone_eic: str = attr.ib(validator=attr.validators.instance_of(str))
+    regelzone_eic: str = attrs.field(validator=attrs.validators.instance_of(str))
     # todo: use EIC validation: https://github.com/Hochfrequenz/BO4E-python/issues/147
 
 
