@@ -5,7 +5,7 @@ and corresponding marshmallow schema for de-/serialization
 
 from typing import Optional
 
-import attr
+import attrs
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -14,7 +14,7 @@ from bo4e.enum.preistyp import Preistyp
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Tarifpreis(Preis):
     """
     Abbildung eines Tarifpreises mit Preistyp und Beschreibung abgeleitet von COM Preis.
@@ -26,11 +26,11 @@ class Tarifpreis(Preis):
 
     # required attributes
     #:  Angabe des Preistypes (z.B. Grundpreis)
-    preistyp: Preistyp = attr.ib(validator=attr.validators.in_(Preistyp))
+    preistyp: Preistyp = attrs.field(validator=attrs.validators.in_(Preistyp))
 
     # optional attributes
     #:  Beschreibung des Preises. Hier können z.B. Preisdetails angegeben sein, beispielsweise "Drehstromzähler".
-    beschreibung: Optional[str] = attr.ib(default=None)
+    beschreibung: Optional[str] = attrs.field(default=None)
 
 
 class TarifpreisSchema(PreisSchema):
