@@ -4,8 +4,8 @@ and corresponding marshmallow schema for de-/serialization
 """
 from decimal import Decimal
 
-import attr
-from attr.validators import matches_re
+import attrs
+from attrs.validators import matches_re
 from marshmallow import fields
 from marshmallow_enum import EnumField  # type:ignore[import]
 
@@ -15,7 +15,7 @@ from bo4e.enum.mengeneinheit import Mengeneinheit
 
 
 # pylint: disable=too-few-public-methods
-@attr.s(auto_attribs=True, kw_only=True)
+@attrs.define(auto_attribs=True, kw_only=True)
 class Zaehlwerk(COM):
     """
     Mit dieser Komponente werden Zählwerke modelliert.
@@ -25,23 +25,23 @@ class Zaehlwerk(COM):
 
     """
 
-    zaehlwerk_id: str = attr.ib(
-        validator=attr.validators.instance_of(str)
+    zaehlwerk_id: str = attrs.field(
+        validator=attrs.validators.instance_of(str)
     )  # Identifikation des Zählwerks (Registers) innerhalb des Zählers.
     # Oftmals eine laufende Nummer hinter der Zählernummer. Z.B. 47110815_1
-    bezeichnung: str = attr.ib(
-        validator=attr.validators.instance_of(str)
+    bezeichnung: str = attrs.field(
+        validator=attrs.validators.instance_of(str)
     )  # Zusätzliche Bezeichnung, z.B. Zählwerk_Wirkarbeit.
     richtung: Energierichtung  # Die Energierichtung, Einspeisung oder Ausspeisung.
-    obis_kennzahl: str = attr.ib(
+    obis_kennzahl: str = attrs.field(
         validator=matches_re(
             r"(?:(1)-((?:[0-5]?[0-9])|(?:6[0-5])):((?:[1-8]|99))\.((?:6|8|9|29))\.([0-9]{1,2}))|"
             r"(?:(7)-((?:[0-5]?[0-9])|(?:6[0-5])):(.{1,2})\.(.{1,2})\.([0-9]{1,2}))"
         )
     )  # Die OBIS-Kennzahl für das Zählwerk, die festlegt, welche auf die gemessene Größe mit dem Stand gemeldet wird.
     # Nur Zählwerkstände mit dieser OBIS-Kennzahl werden an diesem Zählwerk registriert.
-    wandlerfaktor: Decimal = attr.ib(
-        validator=attr.validators.instance_of(Decimal)
+    wandlerfaktor: Decimal = attrs.field(
+        validator=attrs.validators.instance_of(Decimal)
     )  # Mit diesem Faktor wird eine Zählerstandsdifferenz multipliziert, um zum eigentlichen Verbrauch im Zeitraum
     # zu kommen.
     einheit: Mengeneinheit  # Die Einheit der gemessenen Größe, z.B. kWh
