@@ -7,7 +7,7 @@ class ArithmetischeOperation(StrEnum):
     Mit dieser Aufzählung können arithmetische Operationen festgelegt werden.
     """
 
-    ADDITION = "ADDITION"
-    SUBTRAKTION = "SUBTRAKTION"
-    MULTIPLIKATION = "MULTIPLIKATION"
-    DIVISION = "DIVISION"
+    ADDITION = "ADDITION"  #: Es wird addiert
+    SUBTRAKTION = "SUBTRAKTION"  #: Es wird subtrahiert
+    MULTIPLIKATION = "MULTIPLIKATION"  #: Es wird multipliziert
+    DIVISION = "DIVISION"  #: Es wird dividiert
