@@ -6,6 +6,8 @@ from bo4e.com.menge import Menge, MengeSchema
 from bo4e.enum.mengeneinheit import Mengeneinheit
 
 example_menge = Menge(wert=Decimal(3.41), einheit=Mengeneinheit.MWH)
+# see issue https://github.com/Hochfrequenz/BO4E-python/issues/249
+example_menge_dict = {"wert": "3.410000000000000142108547152020037174224853515625", "einheit": "MWH"}
 
 
 class TestMenge:
